# Copyright (C) 2001 Stfane Fermigier <sf@fermigier.com> and
# Nuxeo SARL <contact@nuxeo.com>.
# See licence info at the end of this file.

"""NuxDocuments

"""

__version__='$Revision: 1.7 $'[11:-2]

from OFS.SimpleItem import SimpleItem, Item_w__name__
from OFS.ObjectManager import ObjectManager
from OFS.Cache import Cacheable
from OFS.History import Historical
import Acquisition
from DateTime.DateTime import DateTime

from AccessControl import ClassSecurityInfo
from Globals import HTML, HTMLFile, DTMLFile, MessageDialog, InitializeClass

from urllib import quote
import re, string

import plugins


class NuxDocument(SimpleItem, ObjectManager):
  # (SimpleItem):
  # (CatalogAware, SimpleItem, Acquisition.Implicit, 
  # PropertyManager, Historical, Cacheable, Item_w__name__):
  # + ElementWithTitle (XXX ???)

  index_html = None # Prevent accidental acquisition (XXX ???)

  _raw = _text = _html = ''

  security = ClassSecurityInfo()

  #
  # Constructor
  #
  def __init__(self, id='', title='', file='', mime_type=''):
    self._setId(id)
    self._edit(title, file, mime_type)

  def _edit(self, title, file, mime_type):
    if type(file) is not type(''): 
      file = file.read()
    if title:
      self.title = title
    self.publication_date = DateTime()
    self._raw = file

    if file:
      self.convert(mime_type)

  def convert(self, mime_type):
    file = self.getRaw()
    plugin = plugins.choosePlugin(file, mime_type)
    self.mime_type = plugin.mime_type

    if plugin != plugins.Dumb:
      try:
        converter = plugin.Converter(self.id, file)
      except:
        converter = plugins.Dumb.Converter(self.id, file)
    else:
      converter = plugin.Converter(self.id, file)

    self._text = converter.getText()
    self._html = converter.getHtml()
    for image_name in converter.getImageNames():
      self.manage_addImage(image_name, converter.getImage(image_name))

  #
  # Accessors / rendering
  #
  security.declarePrivate('getHtml')
  def getHtml(self):
    return self._html

  security.declarePrivate('getRaw')
  def getRaw(self):
    return self._raw
  
  security.declareProtected('View', 'MimeType')
  def MimeType(self):
    """This document's mime-type"""
    return self.mime_type

  security.declareProtected('View', 'document_src')
  def document_src(self, REQUEST=None, RESPONSE=None):
    """Unprocessed document source."""

    if RESPONSE is not None:
      RESPONSE.setHeader('Content-Type', self.mime_type)
    return self.getRaw()

  security.declareProtected('FTP', 'document_src')
  def manage_FTPget(self):
    "Get source for FTP download"

    return self.getRaw()

  security.declareProtected('view', 'PrincipiaSearchSource')
  def PrincipiaSearchSource(self):
    return self._text
    #return string.join(re.split(r'[^%s]+' % string.letters, self._text))

  security.declareProtected('view', 'SearchableText')
  def SearchableText(self):
    return "%s %s %s" % (
      self.title, self.Description(), self.PrincipiaSearchSource())

  security.declareProtected('Edit NuxDocument', 'PUT')
  def PUT(self, REQUEST, RESPONSE):
    "Handle HTTP/FTP PUT requests."

    self.dav__init(REQUEST, RESPONSE)
    self.html_src = REQUEST.get('BODY', '')
    self.updateState()
    self.ZCacheable_invalidate()
    self.reindex_object()
    RESPONSE.setStatus(204)
    return RESPONSE

InitializeClass(NuxDocument)

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
# 
# vim:et:ts=2:ai
