#!/usr/local/bin/python

import sys, os, unittest, re, glob
sys.path.insert(0, '..')
sys.path.insert(0, os.environ.get('ZOPE_HOME', '../../..')+'/lib/python/')
import plugins, string

class FileTypeMatchTestCase(unittest.TestCase):
  def test_accept(self):
    for fn in glob.glob('test[0-9].*'):
      if re.match('.*\.doc$', fn):
        self.assertEquals(
          plugins.MSWord.acceptFile(open(fn).read()), 1)
        self.assertEquals(
          plugins.PDF.acceptFile(open(fn).read()), 0)
        self.assertEquals(
          plugins.Dumb.acceptFile(open(fn).read()), 1)
      elif re.match('.*\.pdf$', fn):
        self.assertEquals(
          plugins.MSWord.acceptFile(open(fn).read()), 0)
        self.assertEquals(
          plugins.PDF.acceptFile(open(fn).read()), 1)
        self.assertEquals(
          plugins.Dumb.acceptFile(open(fn).read()), 1)
      else:
        self.assertEquals(
          plugins.MSWord.acceptFile(open(fn).read()), 0)
        self.assertEquals(
          plugins.PDF.acceptFile(open(fn).read()), 0)
        self.assertEquals(
          plugins.Dumb.acceptFile(open(fn).read()), 1)

  def test_choose(self):
    for fn in glob.glob('test[0-9].*'):
      if re.match('.*\.doc$', fn):
        self.assertEquals(
          plugins.choosePlugin(open(fn).read()), plugins.MSWord)
      elif re.match('.*\.pdf$', fn):
        self.assertEquals(
          plugins.choosePlugin(open(fn).read()), plugins.PDF)
      else:
        self.assertEquals(
          plugins.choosePlugin(open(fn).read()), plugins.Dumb)


class ConverterTestCase(unittest.TestCase):

  def test_Base(self):
    doc = plugins.base.ConverterBase('toto', 'titi')

    self.assertEquals(doc.getRaw(), 'titi')
    self.assertEquals(doc.getHtml(), '')
    self.assertEquals(doc.getText(), '')
    self.assertEquals(doc.getImageNames(), [])
    self.assertRaises(KeyError, doc.getImage, '')

  
  #def test_Inert(self):
  #  doc = plugins.Inert.Inert()
  #  doc.edit('toto')
#
#    self.assertEquals(doc._data, 'toto')
#    self.assertEquals(doc.mime_type, '???/???') # XXX: fix this

  def loadMSWordFile(self, name):
    self.doc = plugins.MSWord.Converter(
      name, open('%s.doc' % name).read())

  def checkWordContentAscii(self):
    self.assertEquals(
    	string.count(self.doc.getHtml(), 'Linux rulez. Window$ SuCk$$$.'), 1)
    self.assertEquals(
    	string.count(self.doc.getText(), 'Linux rulez. Window$ SuCk$$$.'), 1)

  def checkWordContentUnicode(self):
    self.assertEquals(
    	string.count(self.doc.getHtml(), 'Il fait chaud en t.'), 1)
    self.assertEquals(
    	string.count(self.doc.getText(), 'Il fait chaud en t.'), 1)

  def test_MSWord1(self):
    self.loadMSWordFile('test1')
    self.checkWordContentAscii()

  def test_MSWord2(self):
    self.loadMSWordFile('test2')
    self.checkWordContentAscii()

  def test_MSWord3(self):
    self.loadMSWordFile('test3')
    self.checkWordContentAscii()

  def test_MSWord4(self):
    self.loadMSWordFile('test4')
    self.checkWordContentAscii()

    images_names = self.doc.getImageNames()
    self.assertEquals(len(images_names), 1)
    self.assertEquals(images_names[0], 'test40.png')
    self.assertEquals(len(self.doc.getImage('test40.png')), 5690)

  def test_MSWord5(self):
    self.loadMSWordFile('test5')
    self.checkWordContentUnicode()

if __name__ == '__main__':
  unittest.main()

